package com.ruoyi.system.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.RlDevice;
import com.ruoyi.system.domain.RlModel;
import com.ruoyi.system.mapper.RlModelMapper;
import com.ruoyi.system.service.IRlDeviceService;
import com.ruoyi.system.service.IRlModelService;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * 车辆型号Service业务层处理
 *
 * @author 邱贞招
 * @date 2024-05-13
 */
@Slf4j
@Service
public class RlModelServiceImpl implements IRlModelService
{
    @Resource
    private RlModelMapper rlModelMapper;

    @Autowired
    private IRlDeviceService eDeviceService;


    /**
     * 查询车辆型号
     *
     * @param modelId 车辆型号主键
     * @return 车辆型号
     */
    @Override
    public RlModel selectEModelByModelId(Long modelId)
    {
        RlModel etModel = rlModelMapper.selectEModelByModelId(modelId);
        if(ObjectUtil.isNotNull(etModel)){
            Integer allNum = eDeviceService.selectCountByModelId(modelId);
            etModel.setDeviceNum(allNum);
        }
        return etModel;
    }

    /**
     * 查询车辆型号列表
     *
     * @param rlModel 车辆型号
     * @return 车辆型号
     */
    @Override
    @DataScope(deptAlias = "d")
    public List<RlModel> selectEModelList(RlModel rlModel)
    {
        List<RlModel> etModels = rlModelMapper.selectEModelList(rlModel);
        for(RlModel model: etModels){
            // 投放数量统计
            RlDevice device = new RlDevice();
            device.setModelId(model.getModelId());
            Integer integer = eDeviceService.selectCountByModelId(model.getModelId());
            model.setDeviceNum(integer);
        }
        return etModels;
    }

    /**
     * 新增车辆型号
     *
     * @param etModel 车辆型号
     * @return 结果
     */
    @SneakyThrows
    @Override
    @Transactional
    public int insertEModel(RlModel etModel)
    {
        etModel.setCreateTime(DateUtils.getNowDate());
        int i = rlModelMapper.insertEModel(etModel);
        return i;
    }

    /**
     * 修改车辆型号
     *
     * @param etModel 车辆型号
     * @return 结果
     */
    @SneakyThrows
    @Override
    @Transactional
    public int updateEModel(RlModel etModel)
    {
        etModel.setUpdateTime(DateUtils.getNowDate());
        int i = rlModelMapper.updateEModel(etModel);
        return i;
    }

    /**
     * 批量删除车辆型号
     *
     * @param modelIds 需要删除的车辆型号主键
     * @return 结果
     */
    @Override
    public int deleteEModelByModelIds(Long[] modelIds)
    {
        return rlModelMapper.deleteEModelByModelIds(modelIds);
    }

    /**
     * 删除车辆型号信息
     *
     * @param modelId 车辆型号主键
     * @return 结果
     */
    @Override
    public int deleteEModelByModelId(Long modelId)
    {
        return rlModelMapper.deleteEModelByModelId(modelId);
    }

    @Override
    public int selectAllCount() {
        return rlModelMapper.selectAllCount();
    }

}
